CustomFooter class

自定义底部加载指示器

允许开发者完全自定义加载底部的UI和行为

主要功能:

  • 通过builder自定义UI
  • 支持加载状态回调
  • 支持偏移量变化回调
  • 支持加载开始和结束回调

示例用法:

CustomFooter(
  builder: (context, mode) {
    return Container(
      height: 50.0,
      alignment: Alignment.center,
      child: Text(mode.toString()),
    );
  },
  onModeChange: (mode) {
    print('加载状态变化: $mode');
  },
)

相关组件:

Inheritance

Constructors

CustomFooter({Key? key, required FooterBuilder builder, OffsetCallback? onOffsetChange, ModeChangeCallback<LoadStatus>? onModeChange, AsyncVoidCallback? readyLoading, AsyncVoidCallback? endLoading, double height = 60.0, LoadStyle loadStyle = LoadStyle.showAlways, VoidCallback? onClick})
构造函数
const

Properties

builder FooterBuilder
底部构建器
final
endLoading AsyncVoidCallback?
结束加载回调
final
hashCode int
The hash code for this object.
no setterinherited
height double
指示器的视觉高度
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadStyle LoadStyle
加载更多显示样式
finalinherited
onClick VoidCallback?
用户点击底部时的回调
finalinherited
onModeChange ModeChangeCallback<LoadStatus>?
模式变化回调
final
onOffsetChange OffsetCallback?
偏移量变化回调
final
readyLoading AsyncVoidCallback?
准备加载回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomFooter>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited