CustomHeader class

自定义头部刷新指示器

允许开发者完全自定义刷新头部的UI和行为

主要功能:

  • 通过builder自定义UI
  • 支持刷新状态回调
  • 支持偏移量变化回调
  • 支持刷新开始和结束回调

示例用法:

CustomHeader(
  builder: (context, mode) {
    return Container(
      height: 50.0,
      alignment: Alignment.center,
      child: Text(mode.toString()),
    );
  },
  onModeChange: (mode) {
    print('刷新状态变化: $mode');
  },
)
Inheritance

Constructors

CustomHeader({Key? key, required HeaderBuilder builder, AsyncVoidCallback? readyToRefresh, AsyncVoidCallback? endRefresh, OffsetCallback? onOffsetChange, ModeChangeCallback<RefreshStatus>? onModeChange, VoidCallback? onResetValue, double height = 60.0, Duration completeDuration = const Duration(milliseconds: 600), RefreshStyle refreshStyle = RefreshStyle.follow})
构造函数
const

Properties

builder HeaderBuilder
头部构建器
final
completeDuration Duration
刷新完成或失败时的停留时间
finalinherited
endRefresh AsyncVoidCallback?
结束刷新回调
final
hashCode int
The hash code for this object.
no setterinherited
height double
指示器的视觉高度
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset double
布局偏移量
finalinherited
onModeChange ModeChangeCallback<RefreshStatus>?
模式变化回调
final
onOffsetChange OffsetCallback?
偏移量变化回调
final
onResetValue VoidCallback?
重置值回调
final
readyToRefresh AsyncVoidCallback?
准备刷新回调
final
refreshStyle RefreshStyle
刷新显示样式
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomHeader>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited