IconPosition enum

图标相对于文本的位置枚举

用于控制刷新/加载指示器中图标的位置

  • left: 图标在文本左侧
  • right: 图标在文本右侧
  • top: 图标在文本上方
  • bottom: 图标在文本下方
Inheritance
Available extensions

Values

left → const IconPosition
top → const IconPosition
bottom → const IconPosition

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IconPosition>
A constant List of the values in this enum, in order of their declaration.