IndicatorStateMixin<T extends StatefulWidget, V> mixin

指示器状态混合类,处理位置监听和状态管理

帮助实现下拉刷新和上拉加载指示器所需的通用功能

Superclass constraints
Mixin applications

Properties

activity ScrollActivity?
当前滚动活动
no setter
configuration RefreshConfiguration?
刷新配置
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
floating bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mode ↔ V?
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
refresher SmartRefresher?
刷新控件实例
getter/setter pair
refresherState SmartRefresherState?
刷新控件状态
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildContent(BuildContext context, V? mode) Widget
构建内容,子类必须实现
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
disposeListener() → void
释放监听器资源
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
update() → void
更新UI

Operators

operator ==(Object other) bool
The equality operator.
inherited