LoadIndicatorState<T extends LoadIndicator> class abstract

上拉加载指示器状态管理类

Inheritance
Mixed-in types

Constructors

LoadIndicatorState()

Properties

activity ScrollActivity?
当前滚动活动
no setterinherited
configuration RefreshConfiguration?
刷新配置
getter/setter pairinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
floating bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
lastLoadedHeight double
上一次加载的数据增加的滚动高度
getter/setter pair
lastMaxScrollExtend double
上一次加载完成后的最大滚动范围
getter/setter pair
mode LoadStatus?
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
refresher SmartRefresher?
刷新控件实例
getter/setter pairinherited
refresherState SmartRefresherState?
刷新控件状态
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildContent(BuildContext context, LoadStatus? mode) Widget
构建内容,子类必须实现
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
disposeListener() → void
释放监听器资源
inherited
endLoading() Future<void>
结束加载
override
enterLoading() → void
进入加载状态
finishLoading() → void
完成加载
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onModeChange(LoadStatus? mode) → void
模式变化回调
inherited
onOffsetChange(double offset) → void
超出边缘偏移量回调
inherited
readyToLoad() Future<void>
准备进入加载状态,会等待此函数完成后再调用onLoading
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetValue() → void
回弹后重置值
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
update() → void
更新UI
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited