RefreshIndicator class abstract

下拉刷新指示器抽象类,实现了iOS和Android风格的下拉刷新效果

Inheritance
Implementers

Constructors

RefreshIndicator({Key? key, double height = 60.0, double offset = 0.0, Duration completeDuration = const Duration(milliseconds: 500), RefreshStyle refreshStyle = RefreshStyle.follow})
const

Properties

completeDuration Duration
刷新完成或失败时的停留时间
final
hashCode int
The hash code for this object.
no setterinherited
height double
指示器的视觉高度
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset double
布局偏移量
final
refreshStyle RefreshStyle
刷新显示样式
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited