RefreshIndicatorState<T extends RefreshIndicator> class abstract

下拉刷新指示器状态管理类

Inheritance
Mixed-in types

Constructors

RefreshIndicatorState()

Properties

activity ScrollActivity?
当前滚动活动
no setterinherited
configuration RefreshConfiguration?
刷新配置
getter/setter pairinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
floating bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
mode RefreshStatus?
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
refresher SmartRefresher?
刷新控件实例
getter/setter pairinherited
refresherState SmartRefresherState?
刷新控件状态
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildContent(BuildContext context, RefreshStatus? mode) Widget
构建内容,子类必须实现
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
disposeListener() → void
释放监听器资源
inherited
endRefresh() Future<void>
结束刷新,进入完成或失败状态
override
initState() → void
Called when this object is inserted into the tree.
inherited
needReverseAll() bool
是否需要反转所有内容
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onModeChange(RefreshStatus? mode) → void
模式变化回调
inherited
onOffsetChange(double offset) → void
超出边缘偏移量回调
inherited
readyToRefresh() Future<void>
准备刷新,可以在此实现动画效果
override
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetValue() → void
重置值,子类可以重写以实现自定义逻辑
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
update() → void
更新UI
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited