RefreshLocalizations class

刷新组件的国际化支持

该文件提供了刷新组件所需的多语言支持,包括:

  • 中文、英文、法语、俄语、乌克兰语、意大利语、日语
  • 德语、西班牙语、荷兰语、瑞典语、葡萄牙语和韩语

示例用法:

void main() {
  runApp(
    MaterialApp(
      localizationsDelegates: [
        RefreshLocalizations.delegate,
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,
        GlobalCupertinoLocalizations.delegate,
      ],
      supportedLocales: [
        const Locale('en'), // 英语
        const Locale('zh'), // 中文
        // 其他支持的语言
      ],
      home: MyHomePage(),
    ),
  );
}

下拉刷新组件的国际化支持类

提供多语言支持,包括中文、英文、法语、俄语、乌克兰语、意大利语、日语、德语、西班牙语、荷兰语、瑞典语、葡萄牙语和韩语

Constructors

RefreshLocalizations(Locale locale)
构造函数

Properties

currentLocalization RefreshString
获取当前语言的刷新字符串实例
no setter
hashCode int
The hash code for this object.
no setterinherited
locale Locale
当前本地化语言环境
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) RefreshLocalizations?
从上下文获取刷新本地化实例

Constants

delegate → const RefreshLocalizationsDelegate
刷新本地化代理