initState method
Called when this object is inserted into the tree.
The framework will call this method exactly once for each State object it creates.
Override this method to perform initialization that depends on the location at which this object was inserted into the tree (i.e., context) or on the widget used to configure this object (i.e., widget).
If a State's build method depends on an object that can itself change state, for example a ChangeNotifier or Stream, or some other object to which one can subscribe to receive notifications, then be sure to subscribe and unsubscribe properly in initState, didUpdateWidget, and dispose:
- In initState, subscribe to the object.
- In didUpdateWidget unsubscribe from the old object and subscribe to the new one if the updated widget configuration requires replacing the object.
- In dispose, unsubscribe from the object.
You should not use BuildContext.dependOnInheritedWidgetOfExactType from this method. However, didChangeDependencies will be called immediately following this method, and BuildContext.dependOnInheritedWidgetOfExactType can be used there.
Implementations of this method should start with a call to the inherited
method, as in super.initState().
Implementation
@override
void initState() {
super.initState();
// 如果设置了初始刷新,在渲染完成后触发刷新
if (widget.controller.initialRefresh) {
WidgetsBinding.instance.addPostFrameCallback((_) {
// 检查 mounted 状态,避免在 build 前就 dispose 导致的错误
// 这种情况主要发生在 TabBarView 中
if (mounted) widget.controller.requestRefresh();
});
}
// 绑定状态到控制器
widget.controller._bindState(this);
}