WaterDropMaterialHeader class
水滴效果Material刷新头部
在MaterialClassicHeader基础上添加了水滴动画效果
示例用法:
WaterDropMaterialHeader(
color: Colors.blue,
distance: 60.0,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RefreshIndicator
- MaterialClassicHeader
- WaterDropMaterialHeader
Constructors
Properties
- backgroundColor → Color?
-
背景颜色
finalinherited
- color → Color?
-
刷新指示器的颜色
finalinherited
- completeDuration → Duration
-
刷新完成或失败时的停留时间
finalinherited
- distance → double
-
刷新时距离顶部的距离
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
指示器的视觉高度
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- offset → double
-
布局偏移量
finalinherited
- refreshStyle → RefreshStyle
-
刷新显示样式
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
语义化标签
finalinherited
- semanticsValue → String?
-
语义化值
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< WaterDropMaterialHeader> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited