LoadStatus enum
加载底部的状态枚举
定义了上拉加载过程中可能的各种状态
Values
- idle → const LoadStatus
-
初始状态,可以通过手势上拉触发加载更多
- canLoading → const LoadStatus
-
拖动距离足够,释放后将触发onLoading回调
- loading → const LoadStatus
-
加载中,等待onLoading回调完成
- noMore → const LoadStatus
-
没有更多数据可加载,此状态下不允许继续加载
- failed → const LoadStatus
-
加载失败,初始状态,可以点击重试 如果需要通过上拉触发加载更多,应在RefreshConfiguration中设置enableLoadingWhenFailed = true
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LoadStatus> - A constant List of the values in this enum, in order of their declaration.