LoadingProcessor mixin
上拉加载处理器接口
定义了上拉加载指示器的回调方法
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
endLoading(
) → Future< void> - 准备关闭加载布局,会在完成后回弹
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onModeChange(
LoadStatus? mode) → void - 模式变化回调
-
onOffsetChange(
double offset) → void - 超出边缘偏移量回调
-
readyToLoad(
) → Future< void> - 准备进入加载状态,会等待此函数完成后再调用onLoading
-
resetValue(
) → void - 回弹后重置值
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited