RefreshStatus enum
刷新头部的状态枚举
定义了下拉刷新过程中可能的各种状态
Values
- idle → const RefreshStatus
-
初始状态,未被拖动,或拖动被取消后,或刷新完成后收起
- canRefresh → const RefreshStatus
-
拖动距离足够,释放后将触发onRefresh回调
- refreshing → const RefreshStatus
-
刷新中,等待onRefresh回调完成
- completed → const RefreshStatus
-
刷新完成
- failed → const RefreshStatus
-
刷新失败
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RefreshStatus> - A constant List of the values in this enum, in order of their declaration.