RefreshStyle enum

刷新头部的显示样式枚举

定义了刷新指示器的不同显示风格

Inheritance
Available extensions

Values

follow → const RefreshStyle

指示器始终跟随内容移动

unFollow → const RefreshStyle

指示器跟随内容移动,当指示器到达顶部并完全可见时,不再跟随内容

behind → const RefreshStyle

指示器大小随边界距离缩放,看起来像是显示在内容后面

front → const RefreshStyle

此样式类似于Flutter原生的RefreshIndicator,显示在内容上方

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RefreshStyle>
A constant List of the values in this enum, in order of their declaration.